@@ -146,7 +146,9 @@ randomPolygons <- function(ras = rast(ext(0, 15, 0, 15), res = 1, vals = 0),
 #' @rdname randomPolygons
 #'
 #' @examples
-#' a1 <- terra::vect(cbind(-110, 59), crs = "epsg:4326")
+#' latLong <- terra::crs("+proj=longlat +datum=WGS84 +no_defs")
+#' # "epsg:4326"
+#' a1 <- terra::vect(cbind(-110, 59), crs = latLong)
 #' a2 <- randomPolygon(a1, area = 1e7)
 #'
 #' if (interactive()) {
@@ -155,13 +157,16 @@ randomPolygons <- function(ras = rast(ext(0, 15, 0, 15), res = 1, vals = 0),
 #' }
 #'
 #' if (require("sf", quietly = TRUE)) {
+#'   latLong <- sf::st_crs("+proj=longlat +datum=WGS84 +no_defs")
+#'   # "epsg:4326"
+#'
 #'   b1 <- list(cbind(
 #'     x = c(-122.98, -116.1, -99.2, -106, -122.98),
 #'     y = c(59.9, 65.73, 63.58, 54.79, 59.9)
 #'   )) |>
 #'     sf::st_polygon() |>
 #'     sf::st_sfc() |>
-#'     sf::st_sf(geometry = _, ID = 1L, shinyLabel = "zone2", crs = "epsg:4326")
+#'     sf::st_sf(geometry = _, ID = 1L, shinyLabel = "zone2", crs = latLong)
 #'   b2 <- randomPolygon(b1, area = 1e10)
 #'
 #'   if (interactive()) {
@@ -281,7 +286,8 @@ rndmPolygonMatrix <- function(x, hectares, area) {
     if (missing(area))
       area <- hectares
   }
-  latLong <- crs("epsg:4326")
+  latLong <- terra::crs("+proj=longlat +datum=WGS84 +no_defs")
+  # latLong <- crs("epsg:4326")
   message("Assuming matrix is in latitude/longitude")
   x <- vect(x, type = "points")
   crs(x) <- latLong
